==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-storage-couchdb/src/main/java/org/apache/streampipes/storage/couchdb/impl/DefaultCrudStorage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.storage.couchdb.impl;

import org.apache.streampipes.model.shared.api.Storable;
import org.apache.streampipes.storage.api.CRUDStorage;
import org.apache.streampipes.storage.couchdb.dao.AbstractDao;

import org.lightcouch.CouchDbClient;

import java.util.function.Supplier;

public class DefaultCrudStorage<T extends Storable> extends AbstractDao<T> implements CRUDStorage<T> {

  public DefaultCrudStorage(Supplier<CouchDbClient> couchDbClientSupplier,
                            Class<T> clazz) {
    super(couchDbClientSupplier, clazz);
  }

  @Override
  public T getElementById(String id) {
    return findWithNullIfEmpty(id);
  }

  @Override
  public T updateElement(T element) {
    update(element);
    return findWithNullIfEmpty(element.getElementId());
  }

  @Override
  public void deleteElement(T element) {
    delete(element.getElementId());
  }
}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-storage-couchdb/src/main/java/org/apache/streampipes/storage/couchdb/impl/DefaultCrudStorage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.storage.couchdb.impl;

import org.apache.streampipes.model.shared.api.Storable;
import org.apache.streampipes.storage.api.CRUDStorage;
import org.apache.streampipes.storage.couchdb.CouchDbStorageManager;
import org.apache.streampipes.storage.couchdb.dao.AbstractDao;

import org.lightcouch.CouchDbClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.function.Supplier;

public class DefaultCrudStorage<T extends Storable> extends AbstractDao<T> implements CRUDStorage<T> {

  private static final Logger LOG = LoggerFactory.getLogger(DefaultCrudStorage.class);

  public DefaultCrudStorage(Supplier<CouchDbClient> couchDbClientSupplier,
      Class<T> clazz) {
    super(couchDbClientSupplier, clazz);
  }

  @Override
  public T getElementById(String id) {
    return findWithNullIfEmpty(id);
  }

  @Override
  public T updateElement(T element) {
    update(element);
    return findWithNullIfEmpty(element.getElementId());
  }

  @Override
  public void deleteElement(T element) {
    try {
      CouchDbStorageManager.INSTANCE.getGenericStorage().deleteAssetLinkToResource(element.getElementId());
    } catch (IOException e) {
      LOG.error("Asset link for " + element.getElementId() + " could not be deleted.");
    }
    delete(element.getElementId());
  }
}
